// bindgen-flags: --rustified-enum ".*"

enum nsCSSPropertyID {
  eCSSProperty_a,
  eCSSProperty_b,

  eCSSProperty_COUNT, /**< <div rustbindgen constant></div> */
  eCSSProperty_COUNT_DUMMY2 = eCSSProperty_COUNT - 1, /**< <div rustbindgen hide></div> */

  eCSSPropertyAlias_aa,
  eCSSPropertyAlias_bb,

  eCSSProperty_COUNT_unexistingVariantValue, /**< <div rustbindgen constant></div> */
};
