// Type definitions from csmith's csmith_minimal.h included in csmith.h .
// Since other header contents are not needed we put them in here
// so the other original header is not needed anymore.

#define int8_t signed char
#define uint8_t unsigned char

#define int16_t short
#define uint16_t unsigned short

#define int32_t int
#define uint32_t unsigned

#define int64_t long long
#define uint64_t unsigned long long
