// bindgen-flags: --fit-macro-constant-types
// Test fitting macro constants into smaller integer types
// Negative values are i8, i16, i32 or i64; others are u8, u16, u32 or u64.
#include "default-macro-constant-type.h"