typedef int int8_t;
typedef int uint8_t;
typedef int int16_t;
typedef int uint16_t;
typedef int int32_t;
typedef int uint32_t;
typedef int int64_t;
typedef int uint64_t;

typedef int8_t i8;
typedef uint8_t u8;
typedef int16_t i16;
typedef uint16_t u16;
typedef int32_t i32;
typedef uint32_t u32;
typedef int64_t i64;
typedef uint64_t u64;

struct Foo {
    int i8;
    int u8;
    int i16;
    int u16;
    int i32;
    int u32;
    int i64;
    int u64;
    int i128;
    int u128;
    int isize;
    int usize;
    int f32;
    int f64;
};
