/// This is a constant that has a docstring
///
/// And expected to be found in generated bindings code too.
const int FOO = 1;

/// This is a constant that has a docstring
///
/// And expected to be found in generated bindings code too.
struct Bar
{
    int baz;
};