#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
pub const NODE_FLAG_FOO: _bindgen_ty_1 = _bindgen_ty_1::NODE_FLAG_FOO;
pub const NODE_FLAG_BAR: _bindgen_ty_1 = _bindgen_ty_1::NODE_FLAG_BAR;
#[repr(u32)]
#[derive(Debug, Copy, Clone, Hash, PartialEq, Eq)]
pub enum _bindgen_ty_1 {
    NODE_FLAG_FOO = 0,
    NODE_FLAG_BAR = 1,
}
