#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
pub type __void_t = ::std::os::raw::c_void;
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, Hash, PartialEq, Eq)]
pub struct __iterator_traits {
    pub _address: u8,
}
