// bindgen-flags: --rustified-enum ".*"

enum __attribute__((packed)) Foo {
    Bar = 0,
    Qux
};

enum __attribute__((packed)) Neg {
    MinusOne = -1,
    One = 1,
};

enum __attribute__((packed)) Bigger {
    Much = 255,
    Larger
};
