#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
#[repr(i32)]
#[derive(Debug, Copy, Clone, Hash, PartialEq, Eq)]
pub enum CSSPseudoClassType {
    empty = 0,
    link = 1,
}
