#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
pub type c_char = ::core::ffi::c_char;
pub type c_double = ::core::ffi::c_double;
pub type c_float = ::core::ffi::c_float;
pub type c_int = ::core::ffi::c_int;
pub type c_long = ::core::ffi::c_long;
pub type c_longlong = ::core::ffi::c_longlong;
pub type c_schar = ::core::ffi::c_schar;
pub type c_short = ::core::ffi::c_short;
pub type c_uchar = ::core::ffi::c_uchar;
pub type c_uint = ::core::ffi::c_uint;
pub type c_ulong = ::core::ffi::c_ulong;
pub type c_ulonglong = ::core::ffi::c_ulonglong;
pub type c_ushort = ::core::ffi::c_ushort;
