// bindgen-flags: --enable-cxx-namespaces -- -x c++ -Itests/headers -include tests/headers/issue-2556/nsStyleStruct.h -include tests/headers/issue-2556/LayoutConstants.h

#include "issue-2556/nsSize.h"
#include "issue-2556/nsStyleStruct.h"
