typedef struct {
    unsigned int bit_1 : 1;
    unsigned int bit_2 : 1;
    unsigned int bit_3 : 1;
    unsigned int bit_4 : 1;
    unsigned int bit_5 : 1;
    unsigned int bit_6 : 1;
    unsigned int bit_7 : 1;
    unsigned int bit_8 : 1;
    unsigned int bit_9 : 1;
    unsigned int bit_10 : 1;
    unsigned int bit_11 : 1;
    unsigned int bit_12 : 1;
    unsigned int bit_13 : 1;
    unsigned int bit_14 : 1;
    unsigned int bit_15 : 1;
    unsigned int bit_16 : 1;
    unsigned int bit_17 : 1;
    unsigned int bit_18 : 1;
    unsigned int bit_19 : 1;
    unsigned int bit_20 : 1;
    unsigned int bit_21 : 1;
    unsigned int bit_22 : 1;
    unsigned int bit_23 : 1;
    unsigned int bit_24 : 1;
    unsigned int bit_25 : 1;
    unsigned int bit_26 : 1;
    unsigned int bit_27 : 1;
    unsigned int bit_28 : 1;
    unsigned int bit_29 : 1;
    unsigned int bit_30 : 1;
    unsigned int bit_31 : 1;
    unsigned int bit_32 : 1;
    unsigned int bit_33 : 1;
    unsigned int bit_34 : 1;
    unsigned int bit_35 : 1;
    unsigned int bit_36 : 1;
    unsigned int bit_37 : 1;
    unsigned int bit_38 : 1;
    unsigned int bit_39 : 1;
    unsigned int bit_40 : 1;
    unsigned int bit_41 : 1;
    unsigned int : 7;
    unsigned int : 16;
    unsigned int : 16;
    unsigned int : 16;
    unsigned int : 16;
    unsigned int : 16;
} capabilities;
