// bindgen-flags: --enable-cxx-namespaces --rustified-enum ".*" --rust-target 1.40
template <typename a, int b> class c { a e[b]; };
class d;
template <typename g, g f> class C { c<d, f> h; };
class i {
  i *j;
  i *k;
  bool l;
};
class d {
  i m;
};
enum n { o, p, q, r, s, t, b, ae, e, ag, ah, ai };
class F {
  C<n, ai> w;
};
