#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
unsafe extern "C" {
    #[link_name = "\u{1}u8"]
    pub static mut u8_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}u16"]
    pub static mut u16_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}u32"]
    pub static mut u32_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}u64"]
    pub static mut u64_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}i8"]
    pub static mut i8_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}i16"]
    pub static mut i16_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}i32"]
    pub static mut i32_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}i64"]
    pub static mut i64_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}f32"]
    pub static mut f32_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}f64"]
    pub static mut f64_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}usize"]
    pub static mut usize_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}isize"]
    pub static mut isize_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}bool"]
    pub static mut bool_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}str"]
    pub static mut str_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}dyn"]
    pub static mut dyn_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}as"]
    pub static mut as_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}async"]
    pub static mut async_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}await"]
    pub static mut await_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}box"]
    pub static mut box_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}crate"]
    pub static mut crate_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}false"]
    pub static mut false_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}fn"]
    pub static mut fn_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}gen"]
    pub static mut gen_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}impl"]
    pub static mut impl_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}in"]
    pub static mut in_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}let"]
    pub static mut let_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}loop"]
    pub static mut loop_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}match"]
    pub static mut match_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}mod"]
    pub static mut mod_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}move"]
    pub static mut move_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}mut"]
    pub static mut mut_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}pub"]
    pub static mut pub_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}ref"]
    pub static mut ref_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}self"]
    pub static mut self_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}Self"]
    pub static mut Self_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}super"]
    pub static mut super_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}trait"]
    pub static mut trait_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}true"]
    pub static mut true_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}try"]
    pub static mut try_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}type"]
    pub static mut type_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}unsafe"]
    pub static mut unsafe_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}use"]
    pub static mut use_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}where"]
    pub static mut where_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}abstract"]
    pub static mut abstract_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}alignof"]
    pub static mut alignof_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}become"]
    pub static mut become_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}final"]
    pub static mut final_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}macro"]
    pub static mut macro_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}offsetof"]
    pub static mut offsetof_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}override"]
    pub static mut override_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}priv"]
    pub static mut priv_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}proc"]
    pub static mut proc_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}pure"]
    pub static mut pure_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}unsized"]
    pub static mut unsized_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}virtual"]
    pub static mut virtual_: ::std::os::raw::c_int;
}
unsafe extern "C" {
    #[link_name = "\u{1}yield"]
    pub static mut yield_: ::std::os::raw::c_int;
}
