#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
unsafe extern "C" {
    pub static mut a: ::std::os::raw::c_int;
}
unsafe extern "C" {
    pub static mut b: ::std::os::raw::c_int;
}
