#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
#[derive(PartialEq, Copy, Clone, Hash, Debug, Default)]
#[repr(C)]
pub struct __BindgenComplex<T> {
    pub re: T,
    pub im: T,
}
unsafe extern "C" {
    pub static mut globalValueFloat: __BindgenComplex<f32>;
}
unsafe extern "C" {
    pub static mut globalValueDouble: __BindgenComplex<f64>;
}
unsafe extern "C" {
    pub static mut globalValueLongDouble: __BindgenComplex<f64>;
}
