#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
unsafe extern "C" {
    #[link_name = "\u{1}_Z1bcz"]
    pub fn b(arg1: ::std::os::raw::c_char, ...) -> ::std::os::raw::c_char;
}
