// bindgen-flags: --use-core --rust-target 1.64 --no-convert-floats
typedef char c_char;
typedef double c_double;
typedef float c_float;
typedef int c_int;
typedef long c_long;
typedef long long c_longlong;
typedef signed char c_schar;
typedef short c_short;
typedef unsigned char c_uchar;
typedef unsigned int c_uint;
typedef unsigned long c_ulong;
typedef unsigned long long c_ulonglong;
typedef unsigned short c_ushort;
