#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
#[repr(C)]
#[derive(Debug, Copy, Clone)]
#[must_use]
pub struct A {
    _unused: [u8; 0],
}
/// <div rustbindgen mustusetype></div>
#[repr(C)]
#[derive(Debug, Copy, Clone)]
#[must_use]
pub struct B {
    _unused: [u8; 0],
}
#[repr(C)]
#[derive(Debug, Copy, Clone)]
pub struct C {
    _unused: [u8; 0],
}
