// bindgen-parse-callbacks: remove-function-prefix-my_custom_prefix_

extern const int my_custom_prefix_var_const_name;

extern int my_custom_prefix_var_mut_name;

void my_custom_prefix_function_name(const int x);

