// bindgen-unstable

/** The point of this test is to _not_ generate these functions. */

inline static int myadd(const int x, const int y) { return x + y; }
static int mysub(const int x, const int y) { return x - y; }
