int u8;
int u16;
int u32;
int u64;
int i8;
int i16;
int i32;
int i64;
int f32;
int f64;
int usize;
int isize;
int bool;
int str;
int dyn;

int as;
int async;
int await;
int box;
int crate;
int false;
int fn;
int gen;
int impl;
int in;
int let;
int loop;
int match;
int mod;
int move;
int mut;
int pub;
int ref;
int self;
int Self;
int super;
int trait;
int true;
int try;
int type;
int unsafe;
int use;
int where;
int abstract;
int alignof;
int become;
int final;
int macro;
int offsetof;
int override;
int priv;
int proc;
int pure;
int unsized;
int virtual;
int yield;
