#![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
/// <div rustbindgen nocopy></div>
#[repr(C)]
#[derive(Debug, Default)]
pub struct CopiableButWait {
    pub whatever: ::std::os::raw::c_int,
}
